@@ -1,5 +1,13 @@
 var NAVTREEINDEX14 =
 {
+"group__spa__pod.html#ga2612ff1c5a0de44d98493019f0de88f4":[8,9,0,218],
+"group__spa__pod.html#ga263e5559ecd6624a92ba2edefc3277cc":[8,9,0,158],
+"group__spa__pod.html#ga26823c0f7c08a7b361451575493c6c9c":[8,9,0,153],
+"group__spa__pod.html#ga26ace0a89aba98cad316969d975c5037":[8,9,0,211],
+"group__spa__pod.html#ga26c770ca09d2170be9f8fe2725901e03":[8,9,0,125],
+"group__spa__pod.html#ga2734f1390d46a1d07a30f2c50ce9f7c0":[8,9,0,78],
+"group__spa__pod.html#ga28626951bcacce86bd5e795f78579df3":[8,9,0,241],
+"group__spa__pod.html#ga2890e7200bc48f0b0cfbb4073957d374":[8,9,0,142],
 "group__spa__pod.html#ga2d61a450e8328ebca28a7ac49850840f":[8,9,0,112],
 "group__spa__pod.html#ga2dd63b5e1306b340295c91f740874a95":[8,9,0,209],
 "group__spa__pod.html#ga2e3f6d030ab0f8ca98819b954f469056":[8,9,0,295],
@@ -241,13 +249,5 @@ var NAVTREEINDEX14 =
 "group__spa__result.html#ga6eb31af26e93aca850932671837ad577":[8,9,8,10,8],
 "group__spa__result.html#ga90c70217108ef23c77b3a3f336fab491":[8,9,8,10,3],
 "group__spa__result.html#ga94d2e4501333b4073e27b472ba94135f":[8,9,8,10,5],
-"group__spa__result.html#ga983f495e5784eb226844b4f540d8dfad":[8,9,8,10,4],
-"group__spa__result.html#gab20d44383dc08a6c9f29126c9ff54a7d":[8,9,8,10,2],
-"group__spa__result.html#gac6610ec8c7368e5c1bf18f92018656f2":[8,9,8,10,7],
-"group__spa__ringbuffer.html":[8,9,8,11],
-"group__spa__ringbuffer.html#ga255dbffcace9c96af41b33e358e1bf1b":[8,9,8,11,5],
-"group__spa__ringbuffer.html#ga48e87cc044b8351f3dcd9d3a66bdf703":[8,9,8,11,2],
-"group__spa__ringbuffer.html#ga636d45b00fa064ed74316528cd21cab5":[8,9,8,11,3],
-"group__spa__ringbuffer.html#ga8d0967ca7c3d8a3dcb39879d46f49cf2":[8,9,8,11,6],
-"group__spa__ringbuffer.html#ga8f1a9c2bb15d923d00803f1dadcccaed":[8,9,8,11,11]
+"group__spa__result.html#ga983f495e5784eb226844b4f540d8dfad":[8,9,8,10,4]
 };
